;*************************************************************
;*********************TM57ML40********************************
;*************************************************************
;-------------------------------------------------------------
;					-F register-
;-------------------------------------------------------------	
INDF 			EQU	00H		;Not a physical register, addressing INDF actually point to the register whose
							;address is contained in the FSR register
TIMER0 			EQU	01H		;Timer 0
PC 				EQU	02H		;0 Program Counter [7~0]
STAT			EQU	03H
GBIT 		EQU	6			;General purpose bit
RAMBANK 	EQU	5			;RAM Bank Select
TO 			EQU	4 			;WDT time out flag
PD 			EQU	3 			;Sleep mode flag
ZFLAG 		EQU	2 			;Zero Flag
DCFLAG 		EQU	1 			;Decimal Carry Flag
CFLAG 		EQU	0 			;Carry Flag

FSR 			EQU	04H		;F-Plane File Select Register
PAD 			EQU	05H		;Port A pin or "data register"
PBD 			EQU	06H		;Port B pin or "data register" state
RSR 			EQU	07H		;R-Plane File Select Register
INTE1			EQU	08H		;Interrupt Enable Group 1, 1=Enable, 0=Disable
PWM0IE 		EQU	7			;PWM0 Interrupt Enable. 1=Enable, 0=Disable
TM2IE 		EQU	6			;Timer2 Interrupt Enable. 1=Enable, 0=Disable
TM1IE 		EQU	5 			;Timer1 Interrupt Enable. 1=Enable, 0=Disable
TM0IE 		EQU	4 			;Timer0 Interrupt Enable. 1=Enable, 0=Disable
WKTIE 		EQU	3 			;Wakeup Timer Interrupt Enable. 1=Enable 0=Disable
							;If WKTIE=0, the WDT/WKT stops in Sleep mode.
XINT2E		EQU	2 			;XINT2 (PB0) falling Interrupt Enable. 1=Enable, 0=Disable
XINT1E 		EQU	1			;XINT1 (PA1) falling Interrupt Enable. 1=Enable 0=Disable
XINT0E 		EQU	0 			;XINT0 (PA0) falling/rising Interrupt Enable. 1=Enable, 0=Disable
INTF1			EQU	09H		;Interrupt Flag Group 1

PWM0I 		EQU	7			;PWM0 interrupt event pending flag, set by H/W while PWM0 overflow
							;0 write 0: clear this flag; write 1: no action.
TM2I 		EQU	6			;Timer2 interrupt event pending flag, set by H/W while Timer2 match
TM1I 		EQU	5			;Timer1 interrupt event pending flag, set by H/W while Timer1 overflow
TM0I 		EQU	4			;Timer0 interrupt event pending flag, set by H/W while Timer0 overflow
WKTI 		EQU	3			;WKT interrupt event pending flag, set by H/W while WKT timeout
XINT2		EQU	2 			;XINT2 pin falling interrupt pending flag, set by H/W at INT2 pin's falling edge.
							;Belongs to XINTA interrupt
XINT1 		EQU	1 			;XINT1 pin falling interrupt pending flag, set by H/W at INT1 pin's falling edge.
XINT0 		EQU	0 			;XINT0 pin falling/rising interrupt pending flag, set by H/W at INT0 pin's

TM1L			EQU	0AH		;Counter low byte,reload data low byte
TM1H			EQU	0BH		;Counter high byte,reload data high byte
PWM0			EQU	0CH		;PWM0 duty 8-bit
TM_CTRL			EQU	0DH		
CLRTM2 		EQU	7			;Timer2 clear and hold when this bit is "1"
RFCSTOP 	EQU	6			;Stop RFC Counter/Loop
CLRRFC 		EQU	5			;Clear RFC Counter
TM1SET 		EQU	4			;Timer1 set FFFFh and hold when this bit is "1"
CLRTM1 		EQU	3			;Timer1 clear and hold when this bit is "1"
CLRPWM0 	EQU	2			;PWM0 clear and hold when this bit is "1"
STOPTM1 	EQU	1			;Stop Timer1 when this bit is "1"
STOPTM0 	EQU	0			;Stop Timer0 when this bit is "1"

INTE2			EQU	0EH		;Interrupt Enable Group 2. 1=Enable, 0=Disable
RFCINTE 	EQU	1 			;R/W 0 RFC Interrupt Enable. 1=Enable, 0=Disable
XINT3E 		EQU	0 			;R/W 0 XINT3 (PB1) falling Interrupt Enable.
INTF2			EQU	0FH		;Interrupt Flag Group 2
RFCINT 		EQU	1			;RFC interrupt event pending flag, set by H/W while RFCCNT overflow
XINT3 		EQU	0 			;XINT3 pin falling/risng interrupt pending flag, set by H/W at INT3 pin's falling
							;edge. Belongs to 
PDD 			EQU	12H		;Port D pin or "data register" state
PED 			EQU	13H		;Port E pin or "data register" state
PFD 			EQU	14H		;Port F pin or "data register" state

PWM1DUTY 		EQU	16H		;PWM1 duty 8-bit
RFCNTH 			EQU	17H		;RFC counter high byte RFCNT[15:8]
RFCNTL 			EQU	18H		;RFC counter low byte RFCNT[7:0]
CFGH 			EQU	1AH		;CFGWord[13:8]
CFGL 			EQU	1BH		;CFGWord[7:0]
;1c~1f Unused Area (for future extension)
;SRAM 20~7f R/W - 2 banks of internal SRAM
;-------------------------------------------------------------
;					-R register-
;-------------------------------------------------------------							
INDR 			EQU	00H		;Not a physical register, addressing INDR actually point to the register whose
							;address is contained in the RSR register
TM0RELOAD 		EQU	01H		;Time0 Reload Data
OPTION			EQU	02H
CAPOLARITY 		EQU	7 		;Timer0 Capture polarity. 0 : High level capture 1: Low level capture
T0CAPTURE 		EQU	6 		;Timer0 works in CAPTURE Mode; 0: Timer0 works in COUNTER Mode
T0IEDGE 		EQU	5 		;1: T0CKI/TKRC falling edge 0: T0CKI/TKRC rising edge for Timer0 Prescaler count
SELT0I 			EQU	4		;T0CKI/TKRC as Timer0 Prescaler clock; 0: Instruction Cycle as Timer0Prescaler clock
TM0PSC 						;BIT 3~0	Timer0 Pre-Scale
							;0000: div1
							;0001: div2
							;0010: div4
							;0011: div8
							;0100: div16
							;0101: div32
							;0110: div64
							;0111: div128
							;1xxx: div256
PWRDOWN 		EQU	03H		;write this register to enter Power-Down Mode
CLRWDT 			EQU	04H		;write this register to clear WDT
PAE				EQU	05H		;PA potr input or output control
PBE 			EQU	06H		;PB potr input or output control

PWM0PRD 		EQU	07H		;PWM0 Period. ff=256
PA_PULL			EQU	08H		;PA pull-up. 0: Enable 1: Disable
PB_PULL			EQU	09H		;PB pull-up. 0: Enable 1: Disable
PUN				EQU	0AH
PFPUN1 		EQU	4			;PF7~4 pull-up, 0=Enable 1:Disable
PFPUN0 		EQU	3			;PF3~0 pull-up, 0=Enable 1:Disable
PEPUN 		EQU	2			;PE3~0 pull-up, 0=Enable 1:Disable
PDPUN1 		EQU	1			;PD2~5 pull-up, 0=Enable 1:Disable
PDPUN0 		EQU	0			;PD0~1 pull-up, 0=Enable 1:Disable
WKTPSC			EQU	0BH
SIRCSEL 					;BIT(6~5) 
							;SIRC
							;00=128K
							;01=32K
							;10=8K
							;11=2K
BUZOUTE 	EQU	4 			;disable BUZZER output to PD1 pin 1: enable BUZZER output to PD1 pin
PWM0E 		EQU	3 			;PWM0 output to PA6 pin 0: PA6 is general I/O pin
PWM1E 		EQU	2			;PWM1 output to PD0 pin 0: PD0 is general I/O pin
WKTPSC 						;bit(1~0) W 11
							;WDT/WKT period,
							;00=3.5ms,
							;01=7ms,
							;10=28ms,
							;11=112ms
TM1_PWM0_PSC	EQU	0CH
BUZ_EN 		EQU	5 			;BUZZER timer counting control
PWM0N 		EQU	4 			;PWM0 negative output to PA6 pin 0: PWM0 positive output


PWM0PSC						;bit(3~2)
							;PWM0 Pre-Scale,
							;00: Fosc
							;01: Fosc/2
							;10: Fosc/4
							;11: Fosc/8
T1CAPTURE 	EQU	1			;1= Timer1 working in capture mode,
							;Timer1 measure CAPT period (time between successive rising or falling edges
							;of CAPT pin)
TM1PSC 		EQU	0			;Timer1 Clock Select,1: Fosc,0: Instruction cycle (Fosc/2)
TM2CTRL			EQU	0DH
INT3EDGE 	EQU	6			;0: INT3 pin falling interrupt; 1: INT3 pin rising interrupt
INT0EDGE 	EQU	5  			;0: INT0 pin falling interrupt; 1: INT0 pin rising interrupt
TIMER2CLK 	EQU	4  			;0: Timer2 Clock is Slow Clock; 1: Timer2 Clock is CPUCLK/128
TIMER2DIV 					;BIT3~2 W 0
							;Timer2 Interrupt is Timer2 clock divide by
							;00: 32768
							;01: 16384
							;10: 8192
							;11: 128
							;LCDCLK 0d.1~0 W 0
							;LCDCLK is Timer2 clock divide by
							;00: 128
							;01: 64
							;10: 32
							;11: 16
TKCTRL			EQU	0EH 
WKTTOUCH 	EQU	7 			;Wake up Timer Source is Touch Key
TM0TOUCHKEY EQU	6 			;Timer0 Source is Touch Key 0: Timer0 Source is CPUCLK/T0CKI
TKSPEED 					;BIT(5~4) W 0
							;Touch Key Oscillation Frequency Select
							;00: Fastest Touch Key clock
							;11: Slowest Touch Key clock
TKSEL 						;BIT(3~0)
							;Touch Key Channel Select
							;0000: TK0
							;0001: TK1
							;
							;1110: TK14
							;1111: NO channel
							
TESTREG			EQU	0FH		;Test reg
CLKCTRL			EQU	10H
KICKE 		EQU	6 			;Enable high gain to kick SXT
ATOSAVE 	EQU	5 			;Auto Save W register and STATUS register when interrupt, and restore them
							;when exit from interrupt
SELSUB 		EQU	4 			;select Slow Clock as cpu clk
STPFCK 		EQU	3 			;stop Fast Clock
SUBE 		EQU	2 			;Slow Clock enable
SUBTYP 						;BIT(1~0) W 0 Slow clock type 0:SXT; 1:SIRC; 2:XRC, 3:TKCLK
LCDCTRL			EQU	11H
LCDICTR 					;BIT(7~6)
							;LCD current control
							;VDD=3V
							;11 => 29.0uA
							;10 => 14.9uA
							;01 => 7.5uA
							;00 => 6uA

LCDDUTY 					;bit(5~3) 
							;LCD/LED Duty
							;000: Static
							;001: 1/2 duty
							;010: 1/3 duty
							;011: 1/4 duty
							;100: 1/5 duty
							;101: 1/6 duty
							;110: 1/7 duty
							;111: 1/8 duty
LCDBIAS 	EQU	2			;LCD Bias 0: 1/2 Bias 1: 1/3 Bias
LCDBRIT 					;bit(1~0)
							;LCD Brightness
							;00: Most darkness
							;11: Most brightness
PDE 			EQU	12H		;PD port input or output controls  
PEE 			EQU	13H		;PE port input or output controls
PFE 			EQU	14H		;PF port input or output controls

LCDPIN1			EQU	15H		;LCD PIN selct
							;15.7 W 0 0: I/O PE3 1: LCDPIN or LEDPIN SEG16
							;15.6 W 0 0: I/O PE2 1: LCDPIN or LEDPIN SEG17
							;15.5 W 0 0: I/O PE1 1: LCDPIN or LEDPIN SEG18
							;15.4 W 0 0: I/O PE0 1: LCDPIN or LEDPIN SEG19
							;15.3 W 0 0: I/O PF7 1: LCDPIN or LEDPIN SEG20
							;15.2 W 0 0: I/O PF6 1: LCDPIN or LEDPIN SEG21
							;15.1 W 0 0: I/O PF5 1: LCDPIN or LEDPIN SEG22
LCDPIN0			EQU	16H	
							;15.0 W 0 0: I/O PF4 1: LCDPIN or LEDPIN SEG23
							;16.7 W 0 0: I/O PF3 1: LCDPIN or LEDPIN SEG24
							;16.6 W 0 0: I/O PF2 1: LCDPIN or LEDPIN SEG25
							;16.5 W 0 0: I/O PF1 1: LCDPIN or LEDPIN SEG26
							;16.4 W 0 0: I/O PF0 1: LCDPIN or LEDPIN SEG27
							;16.3 W 0 0: I/O PD5 1: LCDPIN SEG28 /COM7 or LEDPIN COM7
							;16.2 W 0 0: I/O PD4 1: LCDPIN SEG29 /COM6 or LEDPIN COM6
							;16.1 W 0 0: I/O PD3 1: LCDPIN SEG30 /COM5 or LEDPIN COM5
							;16.0 W 0 0: I/O PD2 1: LCDPIN SEG31 /COM4 or LEDPIN COM4
FIRC_PLL		EQU	17H	
							;CLKSEL 17.7~6 W 01
							;PLLCLK & FIRCCLK select
							;00: PLLCLK=PLLOUT/1 , FIRCCLK = 8M
							;01: PLLCLK=PLLOUT/2 , FIRCCLK = 4M
							;10: PLLCLK=PLLOUT/4 , FIRCCLK = 2M
							;11: PLLCLK=PLLOUT/8 , FIRCCLK = 512K
							;PLLM 17.5~0 W 0 PLLOUT = 32768 * 4 *(64+PLLM)

BUZ				EQU	18H	
							;BUZ_PSC bit(7~6),BUZZER Clock Prescaler
							;00: BUZZER clock is Instruction Cycle divided by 4
							;01: BUZZER clock is Instruction Cycle divided by 8
							;10: BUZZER clock is Instruction Cycle divided by 16
							;11: BUZZER clock is Instruction Cycle divided by 32
							;BUZ_PROD bit(5~0)BUZZER Period Data. BUZZER output is BUZZER Clock divided by BUZ_PROD
RFCCON			EQU	19H	
TM1STPRFC 	EQU 7 			;Timer1 overflow to control RFC
TM0STPRFC 	EQU 6 			;Timer0 overflow to control RFC
CX1E 		EQU 5 			;enable CX1 osc, select CX1 as RFC Counter CLK
CX0E 		EQU 4 			;enable CX0 osc, select CX0 as RFC Counter CLK
RFC3E 		EQU 3 			;select RFC3 pin for RFC loop
RFC2E 		EQU 2 			;select RFC2 pin for RFC loop
RFC1E 		EQU 1 			;select RFC1 pin for RFC loop
RFC0E 		EQU 0 			;select RFC0 pin for RFC loop
                  			
PBWKUP 			EQU 1AH		;bit(7~2) Wake up enable 0:disable
LCD_LED			EQU 1BH
LEDON 		EQU 3 			;LED display on 0: LED display off
LEDTYPE 	EQU 2 			;LED high active 0: low active
SELLED 		EQU 1 			;0: Select LCD1: Select LED
LCDON 		EQU 0 			;LCD Enable 0: Disable

;LCDRAM 40~5f W/R xx LCD RAM. Initial values are not defined.
;34~3f - - not used. Read as 0x00


;*************************************************************
;				Bay  user 
;*************************************************************
ACC_Save			equ		20h
Status_Save			equ		21h


